%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%                                                                           
%   init_pmsm.m                                            
%                                                                         
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; 
close all;
clc;


%% Choose the (sub-)task

task = 1;         % The init-file will automatically load all required parameters regarding each (sub-)task


%% General parameters
MotorName = ['AMK - DS13-250-6-EOW-2600-B5'];

%--- Electrical parameters
R_s		= 0.06;         % [Ohm], Stator resistance
L_s		= 1.3e-3;       % [H], Stator inductance
psi_p   = 0.124049;		% [Vs], permanent magnet linked flux
tau_s   = L_s/R_s;		% [s], stator time constant

U_n = 350;          % [V], nominal voltage
I_n = 138;          % [A], nominal current (RMS)
I_max = 330;        % [A], maximum current (RMS), short time operation (below 6 seconds)

%--- Mechanical parameters
p = 6;                      % [], number of pole pairs 
T_n = 260;                  % [Nm], nominal torque
n_n = 1800;                 % [U/min], nominal speed
P_n = T_n*(2*pi/60)*n_n;    % [W], nominal mechanical output power
n_max = 4000;               % [U/min], maximum speed
J = 1324e-4;                % [kgm^2], inertia
K_M = 1/(3/2 * p * psi_p);  % [1/Vs], motor constant for torque calculation

%--- Inverter parameters
U_DC = 600;         % [V], dc-link voltage
Ta = 62.5e-6;       % [s], inverter switching time
T_sigma = 0.5*Ta;   % [s], inverter time constant as approximation of inverter dead time
                    % no computation time delay of 1*Ta in the Simulink model

%% Specific parameters 

switch task
	case 1
        %--- Exercise. 1: Machinemodel of PMSM
        T_sim = 10;         % [s], duration of simulation
        eps_M_0 = pi/2/p;   % [rad], initial rotor position angle
        omega_M_0 = 0;		% [s^-1], intial angular speed
        T_L	= 0;			% [Nm], initial load torque

        u_soll_a = 10;          % [V], set point for motor voltage in phase a
        u_soll_b = -5;          % [V], set point for motor voltage in phase b
        u_soll_c = -5;          % [V], set point for motor voltage in phase c
        flg_variable_omega = 1;	% 0 = fixed speed equal to initial speed, 1 = variable speed according to mechanical differential equation 

        open('.\pmsm_sim1.mdl')
        msgbox(['Initialisation of task ', num2str(task), ' is done!']);
    
	case 2
        %--- Exercise 2: 	Current Control according to Magnitude Optimum

        T_sim = 1;        % [s], duration of simulation
        i_soll_d =  0;    % [A], given set point for id-current
        T_soll_M = 100;   % [Nm], given set point for torque
        T_L = 0;                    % [Nm], initial load torque
        eps_M_0 = pi/2/p;           % [rad], initial rotor position angle
        n0 = 500;                   % [min^-1], intial speed
        omega_M_0 = n0*pi/30;     % [s^-1], intial angular speed
        flg_variable_omega = 0;     % 0 = fixed speed equal to initial speed, 1 = variable speed according to mechanical differential equation 

        % Design rule: Magnitude Optimum
        T_N = tau_s;                        % [s], Cancel the big time constant of the control plant 
        K_p = R_s * T_N/(T_sigma * 2);      % [V/A], Choose the controller gain for a damping d = 1/sqrt(2) (natural damping)

        open('.\pmsm_sim2.mdl')
        msgbox(['Initialisation of task ', num2str(task), ' is done!']);
        
	case 3
        %--- Exercise 3: Current Control according to Symmetrical Optimum

        T_sim = 1;        % [s], duration of simulation
        i_soll_d =  0;    % [A], given set point for id-current
        T_soll_M = 100;   % [Nm], given set point for torque
        T_L = 0;                    % [Nm], initial load torque
        eps_M_0 = pi/2/p;           % [rad], initial rotor position angle
        n0 = 500;                   % [min^-1], intial speed
        omega_M_0 = n0*pi/30;     % [s^-1], intial angular speed
        flg_variable_omega = 0;     % 0 = fixed speed equal to initial speed, 1 = variable speed according to mechanical differential equation 

        % Design rule: Symmetrical Optimum
        alpha = 2;                              % [], design parameter for control dynamics
        K_p = R_s /alpha * (tau_s/T_sigma);     % [V/A], Controller gain
        T_N = alpha^2 * T_sigma;                % [s], Controller reset time

        % Reference filter
        T_F = T_N;      % [s], PT-1 time constant for filtering the reference variable
        K_F = 1;        % [], gain for reference filter (only time delay)

        open('.\pmsm_sim3.mdl')
        msgbox(['Initialisation of task ', num2str(task), ' is done!']);
    
	case 4
        %--- Exercise 4: Investigating the Control Behavior

        T_sim = 1;        % [s], duration of simulation
        U_MAX = U_DC/2;     % [V], maximum voltage
        i_soll_d =  0;    % [A], given set point for id-current
        T_soll_M = 100;   % [Nm], given set point for torque
        T_L = 0;                    % [Nm], initial load torque
        eps_M_0 = pi/2/p;           % [rad], initial rotor position angle
        n0 = 500;                   % [min^-1], intial speed
        omega_M_0 = n0*pi/30;     % [s^-1], intial angular speed
        flg_variable_omega = 0;     % 0 = fixed speed equal to initial speed, 1 = variable speed according to mechanical differential equation 
        flg_sat_inverter = 0;		% 0 = inverter does not consider the maximum feasible voltage, 1 = inverters considers the maximum feasible voltage 
        flg_consider_limits = 0;    % 0 = controller does not considers the operation limits, 1 = controller tries to satisfy all operation limits

%         open('.\pmsm_sim4.mdl')    % please use pmsm_sim3.mdl as basis for the solution
        msgbox(['Initialisation of task ', num2str(task), ' is done!']);
    
    otherwise 
        msgbox('Initialisation failed!');
end 