%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%                                                                           
%   plot_pmsm.m                                            
%                                                                         
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

% This script will plot all relevant quantaties automatically according the actual task

switch task
	case 1
		%--- Exercise. 1: Machinemodel of PMSM
		fig_i_mess = figure('NumberTitle','off','name','Currents');
            plot(t,i_mess(:,1), t,i_mess(:,2), t,i_mess(:,3));
			legend('i_{x,a}', 'i_{x,b}', 'i_{x,c}');
			ylabel('i_x in A')
			xlabel('t in s');
			grid on; zoom on;
        fig_mech_mess = figure('NumberTitle','off','name','Mechanical quantaties');
            subplot(3,1,1);
				plot(t,mech_mess(:,1));
				ylabel('\epsilon_M (rad)');
				grid on; zoom on;
            subplot(3,1,2);
				plot(t,mech_mess(:,2));
				ylabel('\omega_M in min^{-1}');
				grid on; zoom on;
            subplot(3,1,3);
				plot(t,mech_mess(:,3));
				ylabel('T_M in Nm');
				xlabel('t in s');
				grid on; zoom on;
    
	case {2,3}
        %--- Exercise 2 or 3: 	Current Control
        fig_i_mess = figure('NumberTitle','off','name','Currents');
			subplot(3,1,1);
				plot(t,i_mess(:,1), t,i_mess(:,2), t,i_mess(:,3));
				legend('i_{x,r}', 'i_{x,s}', 'i_{x,t}');
				xlabel('t in s');
				ylabel('i_x in A');
				grid on; zoom on;
			subplot(3,1,2);
				plot(t,i_x_ab(:,1), t,i_x_ab(:,2));
				legend('i_\alpha', 'i_\beta');
				grid on; zoom on;
				ylabel('i_x in A');
			subplot(3,1,3);
				plot(t,i_x_dq(:,1),'b',...
						 i_w_dq.time,i_w_dq.signals.values(:,1),'--b',...
					   t,i_x_dq(:,2),'r',...
						 i_w_dq.time,i_w_dq.signals.values(:,2),'--r');
				legend('i_{x,d}','i_{w,d}','i_{x,q}','i_{w,q}');
				ylabel('i_x in A');
				xlabel('t in s');
				grid on; zoom on;
		
        fig_mech_mess = figure('NumberTitle','off','name','Mechanical quantaties');
			subplot(3,1,1);
				plot(t,mech_mess(:,1));
				ylabel('\epsilon_M (rad)');
				grid on; zoom on;
            subplot(3,1,2);
				plot(t,mech_mess(:,2));
				ylabel('\omega_M in min^{-1}');
				grid on; zoom on;
            subplot(3,1,3);
				plot(t,mech_mess(:,3));
				ylabel('T_M in Nm');
				xlabel('t in s');
				grid on; zoom on;

        fig_u = figure('NumberTitle','off','name','Voltages');
			subplot(3,1,1);
				plot(t,u_w_dq(:,1), t,u_w_dq(:,2));
				legend('u_{w,d}', 'u_{w,q}');
				ylabel('u in V');
				grid on; zoom on;
            subplot(3,1,2);
				plot(t,u_w_ab(:,1), t,u_w_ab(:,2));
				legend('u_{w,\alpha}', 'u_{w,\beta}');
				ylabel('u in V');
				grid on; zoom on;
            subplot(3,1,3);
				plot(t,u_w_rst(:,1), t, u_w_rst(:,2), t, u_w_rst(:,3));     
				hold on;
				legend('u_{w,r}', 'u_{w,s}', 'u_{w,t}');
				ylabel('u in V');
				xlabel('t in s');
				grid on; zoom on;
        
	case 4
        %--- Exercise 4: Investigating the Control Behavior
        fig_i_mess = figure('NumberTitle','off','name','Currents');
			subplot(3,1,1);
				plot(t,i_mess(:,1), t,i_mess(:,2), t,i_mess(:,3));
				legend('i_{x,r}', 'i_{x,s}', 'i_{x,t}');
				xlabel('t in s');
				ylabel('i_x in A');
				grid on; zoom on;
			subplot(3,1,2);
				plot(t,i_x_ab(:,1), t,i_x_ab(:,2));
				legend('i_\alpha', 'i_\beta');
				grid on; zoom on;
				ylabel('i_x in A');
			subplot(3,1,3);
				plot(t,i_x_dq(:,1),'b',...
						 i_w_dq.time,i_w_dq.signals.values(:,1),'--b',...
					   t,i_x_dq(:,2),'r',...
						 i_w_dq.time,i_w_dq.signals.values(:,2),'--r');
				legend('i_{x,d}','i_{w,d}','i_{x,q}','i_{w,q}');
				ylabel('i_x in A');
				xlabel('t in s');
				grid on; zoom on;
		
        fig_mech_mess = figure('NumberTitle','off','name','Mechanical quantaties');
			subplot(3,1,1);
				plot(t,mech_mess(:,1));
				ylabel('\epsilon_M (rad)');
				grid on; zoom on;
            subplot(3,1,2);
				plot(t,mech_mess(:,2));
				ylabel('\omega_M in min^{-1}');
				grid on; zoom on;
            subplot(3,1,3);
				plot(t,mech_mess(:,3));
				ylabel('T_M in Nm');
				xlabel('t in s');
				grid on; zoom on;

        fig_u = figure('NumberTitle','off','name','Voltages');
			subplot(4,1,1);
				plot(t,u_w_dq(:,1), t,u_w_dq(:,2));
				legend('u_{w,d}', 'u_{w,q}');
				ylabel('u in V');
				grid on; zoom on;
            subplot(4,1,2);
				plot(t,u_w_ab(:,1), t,u_w_ab(:,2));
				legend('u_{w,\alpha}', 'u_{w,\beta}');
				ylabel('u in V');
				grid on; zoom on;
            subplot(4,1,3);
				plot(t,u_w_rst(:,1), t, u_w_rst(:,2), t, u_w_rst(:,3));     
				hold on;
				legend('u_{w,r}', 'u_{w,s}', 'u_{w,t}');
				ylabel('u in V');
				xlabel('t in s');
				grid on; zoom on;
            subplot(4,1,4);
				plot(u_x_rst.time,u_x_rst.signals.values(:,1),...
						 u_x_rst.time,u_x_rst.signals.values(:,2),...
						 u_x_rst.time,u_x_rst.signals.values(:,3));     
				hold on;
				legend('u_{x,r}', 'u_{x,s}', 'u_{x,t}');
				ylabel('u in V');
				xlabel('t in s');
				grid on; zoom on;
   	
    otherwise
        msgbox('Graphical representation failed')
end 